-- Categories of forums
CREATE TABLE forum_categories (
  id INT AUTO_INCREMENT PRIMARY KEY,
  name VARCHAR(100) NOT NULL,
  slug VARCHAR(100) NOT NULL UNIQUE,
  description TEXT,
  is_deleted TINYINT(1) DEFAULT 0
);

-- Topics within categories
CREATE TABLE forum_topics (
  id INT AUTO_INCREMENT PRIMARY KEY,
  category_id INT NOT NULL,
  user_id INT NOT NULL,
  title VARCHAR(255) NOT NULL,
  slug VARCHAR(255) NOT NULL UNIQUE,
  created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
  is_deleted TINYINT(1) DEFAULT 0,
  FOREIGN KEY (category_id) REFERENCES forum_categories(id)
);

-- Posts within topics
CREATE TABLE forum_posts (
  id INT AUTO_INCREMENT PRIMARY KEY,
  topic_id INT NOT NULL,
  user_id INT NOT NULL,
  content TEXT NOT NULL,
  created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
  is_deleted TINYINT(1) DEFAULT 0,
  FOREIGN KEY (topic_id) REFERENCES forum_topics(id)
);

ALTER TABLE forum_categories
    ADD COLUMN parent_id INT DEFAULT NULL,
    ADD COLUMN sort_order INT DEFAULT 0;

CREATE INDEX idx_forum_parent ON forum_categories(parent_id);


CREATE TABLE forum_users (
  id            INT AUTO_INCREMENT PRIMARY KEY,
  ems_user_id   INT          NULL,
  username      VARCHAR(100) NOT NULL,
  email         VARCHAR(255) NOT NULL,
  password_hash VARCHAR(255) NULL,
  created_at    DATETIME     NOT NULL DEFAULT CURRENT_TIMESTAMP,
  INDEX (ems_user_id)
);

ALTER TABLE forum_users
  ADD COLUMN avatar_url    VARCHAR(255)    NULL,
  ADD COLUMN signature     TEXT            NULL,
  ADD COLUMN joined_at     DATETIME        NOT NULL DEFAULT CURRENT_TIMESTAMP,
  ADD COLUMN last_seen     DATETIME        NULL;

ALTER TABLE forum_topics
  ADD COLUMN is_locked TINYINT(1) NOT NULL DEFAULT 0,
  ADD INDEX idx_forum_topics_locked (is_locked);

CREATE TABLE forum_usergroups (
    id INT AUTO_INCREMENT PRIMARY KEY,
    name VARCHAR(50) NOT NULL UNIQUE,
    is_system TINYINT(1) DEFAULT 0, -- 1 = system group like Fed Head
    is_deleted TINYINT(1) DEFAULT 0
);

CREATE TABLE forum_permissions (
    id INT AUTO_INCREMENT PRIMARY KEY,
    code VARCHAR(50) NOT NULL UNIQUE,
    label VARCHAR(100) NOT NULL
);

CREATE TABLE forum_usergroup_permissions (
    id INT AUTO_INCREMENT PRIMARY KEY,
    usergroup_id INT NOT NULL,
    permission_id INT NOT NULL,
    allowed TINYINT(1) DEFAULT 0,
    UNIQUE KEY usergroup_permission_unique (usergroup_id, permission_id),
    FOREIGN KEY (usergroup_id) REFERENCES forum_usergroups(id) ON DELETE CASCADE,
    FOREIGN KEY (permission_id) REFERENCES forum_permissions(id) ON DELETE CASCADE
);

INSERT INTO forum_permissions (code, label) VALUES
    ('can_view_topics', 'Can View Topics'),
    ('can_post_topic', 'Post Topic'),
    ('can_reply_topics', 'Reply to Topics'),
    ('can_edit_own_topics', 'Edit Own Topics'),
    ('can_edit_others_topics', 'Edit Other\'s Topics'),
    ('can_delete_own_topics', 'Delete Own Topics'),
    ('can_delete_others_topics', 'Delete Other\'s Topics'),
    ('can_lock_own_topics', 'Lock Own Topics'),
    ('can_lock_others_topics', 'Lock Other\'s Topics'),
    ('can_pin_own_topics', 'Pin Own Topic'),
    ('can_pin_others_topics', 'Pin Other\'s Topics'),
    ('can_moderate_topics', 'Can Moderate Topics'),
    ('can_use_pm', 'Can Use Private Messaging'),
    ('have_avatar', 'Have Avatar'),
    ('have_signature', 'Have Signature');

INSERT INTO forum_usergroups (id, name, is_system) VALUES
    (1, 'Fan', 1),
    (2, 'Alumni', 1),
    (3, 'Handler', 1),
    (4, 'Fed Head', 1);

INSERT INTO forum_usergroup_permissions (usergroup_id, permission_id, allowed)
SELECT 4, id, 1 FROM forum_permissions;

-- Alter existing tables (ensure forum_users and forum_topics exist beforehand)
ALTER TABLE forum_users
    ADD COLUMN name VARCHAR(100) DEFAULT NULL,
    ADD COLUMN birthday DATE DEFAULT NULL,
    ADD COLUMN bio VARCHAR(300) DEFAULT NULL,
    ADD COLUMN discord VARCHAR(100) DEFAULT NULL,
    ADD COLUMN facebook VARCHAR(100) DEFAULT NULL,
    ADD COLUMN instagram VARCHAR(100) DEFAULT NULL,
    ADD COLUMN threads VARCHAR(100) DEFAULT NULL,
    ADD COLUMN twitter VARCHAR(100) DEFAULT NULL,
    ADD COLUMN bluesky VARCHAR(100) DEFAULT NULL,
    ADD COLUMN tiktok VARCHAR(100) DEFAULT NULL,
    ADD COLUMN twitch VARCHAR(100) DEFAULT NULL,
    ADD COLUMN youtube_url VARCHAR(255) DEFAULT NULL,
    ADD COLUMN website_url VARCHAR(255) DEFAULT NULL;

ALTER TABLE forum_topics
    ADD COLUMN is_pinned TINYINT(1) NOT NULL DEFAULT 0;

ALTER TABLE `forum_categories`
  ADD COLUMN `is_locked` TINYINT(1) NOT NULL DEFAULT 0 AFTER `sort_order`;

-- Version 1.1 SQL
CREATE TABLE `forum_user_permissions` (
  `id` INT NOT NULL AUTO_INCREMENT PRIMARY KEY,
  `user_id` INT NOT NULL,
  `permission_id` INT NOT NULL,
  `allowed` TINYINT(1) NOT NULL,
  UNIQUE KEY (`user_id`, `permission_id`),
  FOREIGN KEY (`user_id`) REFERENCES `forum_users`(`id`) ON DELETE CASCADE,
  FOREIGN KEY (`permission_id`) REFERENCES `forum_permissions`(`id`) ON DELETE CASCADE
) ENGINE=InnoDB CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

