<?php
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);
require_once __DIR__ . '/forum_bootstrap.php';
require_once __DIR__ . '/../auth.php';
requireLogin();

$user = currentUser();
if ((int)$user['group_id'] < 9) {
    exit('Unauthorized');
}

require_once __DIR__ . '/../../config/db.php';

// Handle create
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['new_name'])) {
    $name = trim($_POST['new_name']);
    $desc = trim($_POST['new_description']);
    $slug = strtolower(preg_replace('/[^a-z0-9]+/', '-', $name));
    $parentId = $_POST['new_parent_id'] !== '' ? (int)$_POST['new_parent_id'] : null;
    $sortOrder = (int)$_POST['new_sort_order'];
    $isLocked = isset($_POST['new_is_locked']) ? 1 : 0;

    if ($name !== '') {
        $stmt = $db->prepare("INSERT INTO forum_categories (name, slug, description, parent_id, sort_order, is_locked) VALUES (?, ?, ?, ?, ?, ?)");
        $stmt->bind_param('sssiii', $name, $slug, $desc, $parentId, $sortOrder, $isLocked);
        $stmt->execute();
        header('Location: categories.php');
        exit;
    }
}

// Handle delete
if (isset($_GET['delete'])) {
    $id = (int)$_GET['delete'];
    $db->query("UPDATE forum_categories SET is_deleted = 1 WHERE id = $id");
    header('Location: categories.php');
    exit;
}

// Handle update
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['edit_id'])) {
    $id = (int)$_POST['edit_id'];
    $name = trim($_POST['edit_name']);
    $desc = trim($_POST['edit_description']);
    $slug = strtolower(preg_replace('/[^a-z0-9]+/', '-', $name));
    $parentId = $_POST['edit_parent_id'] !== '' ? (int)$_POST['edit_parent_id'] : null;
    $sortOrder = (int)$_POST['edit_sort_order'];
    $isLocked = isset($_POST['edit_is_locked']) ? 1 : 0;

    $stmt = $db->prepare("UPDATE forum_categories SET name = ?, slug = ?, description = ?, parent_id = ?, sort_order = ?, is_locked = ? WHERE id = ?");
    $stmt->bind_param('sssiiii', $name, $slug, $desc, $parentId, $sortOrder, $isLocked, $id);
    $stmt->execute();
    header('Location: categories.php');
    exit;
}

// Fetch categories
$result = $db->query("SELECT * FROM forum_categories WHERE is_deleted = 0 ORDER BY parent_id ASC, sort_order ASC");
$raw = $result->fetch_all(MYSQLI_ASSOC);

// Group by parent
$categories = [];
foreach ($raw as $row) {
    $categories[(int)$row['parent_id']][] = $row;
}

// Recursive helper to render dropdown options
function renderCategoryOptions($groups, $parentId = 0, $prefix = '') {
    if (empty($groups[$parentId])) {
        return;
    }
    foreach ($groups[$parentId] as $cat) {
        echo '<option value="' . $cat['id'] . '">' . $prefix . htmlspecialchars($cat['name']) . '</option>';
        renderCategoryOptions($groups, $cat['id'], $prefix . '&nbsp;&nbsp;');
    }
}

// Recursive helper to render table rows
function renderCategoryRows($groups, $parentId = 0, $prefix = '') {
    if (empty($groups[$parentId])) {
        return;
    }
    foreach ($groups[$parentId] as $cat) {
        ?>
        <tr data-id="<?= $cat['id'] ?>">
            <form method="post">
                <input type="hidden" name="edit_id" value="<?= $cat['id'] ?>">
                <td><input type="text" name="edit_name" value="<?= htmlspecialchars($prefix . $cat['name']) ?>" required></td>
                <td><textarea name="edit_description" rows="2"><?= htmlspecialchars($cat['description']) ?></textarea></td>
                <td>
                    <select name="edit_parent_id">
                        <option value="">(No parent)</option>
                        <?php renderEditOptions($groups, 0, '', $cat['parent_id'], $cat['id']); ?>
                    </select>
                </td>
                <td><input type="number" name="edit_sort_order" value="<?= (int)$cat['sort_order'] ?>"></td>
                <td><input type="checkbox" name="edit_is_locked" value="1" <?= $cat['is_locked'] ? 'checked' : '' ?>></td>
                <td>
                    <button type="submit">Save</button>
                    <a href="?delete=<?= $cat['id'] ?>" onclick="return confirm('Delete this category?')">Delete</a>
                </td>
            </form>
        </tr>
        <?php
        renderCategoryRows($groups, $cat['id'], $prefix . '─ ');
    }
}

// Helper for edit dropdown excluding self
function renderEditOptions($groups, $parentId = 0, $prefix = '', $currentParent = null, $selfId = null) {
    if (empty($groups[$parentId])) {
        return;
    }
    foreach ($groups[$parentId] as $c) {
        if ($c['id'] === (int)$selfId) continue;
        $selected = ($c['id'] == $currentParent) ? ' selected' : '';
        echo '<option value="' . $c['id'] . '"' . $selected . '>' . $prefix . htmlspecialchars($c['name']) . '</option>';
        renderEditOptions($groups, $c['id'], $prefix . '&nbsp;&nbsp;', $currentParent, $selfId);
    }
}
?>
<!DOCTYPE html>
<html>
<head>
    <meta charset="UTF-8">
    <title>Manage Forum Categories</title>
    <link rel="stylesheet" href="../css/admin.css">
    <script src="https://cdn.jsdelivr.net/npm/sortablejs@1.15.0/Sortable.min.js"></script>
</head>
<body>
<div class="dashboard-wrapper">
    <h1>Manage Forum Categories</h1>

    <h2>Add New Category</h2>
    <form method="post">
        <label>Name:<br><input type="text" name="new_name" required></label><br><br>
        <label>Description:<br><textarea name="new_description" rows="3"></textarea></label><br><br>
        <label>Parent Forum:<br>
            <select name="new_parent_id">
                <option value="">(No parent)</option>
                <?php renderCategoryOptions($categories); ?>
            </select>
        </label><br><br>
        <label>Sort Order:<br><input type="number" name="new_sort_order" value="0"></label><br>
        <label><input type="checkbox" name="new_is_locked"> Locked</label><br><br>
        <button type="submit">Add Category</button>
    </form>

    <hr>

    <h2>Existing Categories</h2>
    <?php if (empty($raw)): ?>
        <p>No categories available.</p>
    <?php else: ?>
        <table class="admin-table">
            <thead>
                <tr>
                    <th>Name</th>
                    <th>Description</th>
                    <th>Parent</th>
                    <th>Sort</th>
                    <th>Locked</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody id="sortableCategories">
                <?php renderCategoryRows($categories); ?>
            </tbody>
        </table>
    <?php endif ?>
</div>
<script>
document.addEventListener('DOMContentLoaded', function () {
    new Sortable(document.getElementById('sortableCategories'), {
        animation: 150,
        handle: 'td',
        onEnd: function () {
            const order = [];
            document.querySelectorAll('#sortableCategories tr').forEach((row, index) => {
                order.push({ id: row.dataset-id || row.dataset.id, sort: index });
            });

            fetch('update_sort_order.php', {
                method: 'POST',
                headers: { 'Content-Type': 'application/json' },
                body: JSON.stringify(order)
            })
            .then(res => res.ok ? console.log('Sort order saved') : alert('Failed to save sort order'));
        }
    });
});
</script>
</body>
</html>
