<?php
// admin/forums/edit_user_permissions.php

ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);
require_once __DIR__ . '/forum_bootstrap.php';
require_once __DIR__ . '/../auth.php';
requireLogin();

$currentUser = currentUser();
if ((int)$currentUser['group_id'] < 9) {
    exit('Unauthorized');
}

require_once __DIR__ . '/../../config/db.php';

// Determine target user ID
$targetUserId = 0;
if (isset($_GET['user_id'])) {
    $targetUserId = (int) $_GET['user_id'];
} elseif (!empty($_POST['user_id'])) {
    $targetUserId = (int) $_POST['user_id'];
}
if (!$targetUserId) {
    exit('No user specified.');
}

$message = '';
// Handle POST actions
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Reset overrides
    if (isset($_POST['reset_all'])) {
        $stmt = $db->prepare('DELETE FROM forum_user_permissions WHERE user_id = ?');
        $stmt->bind_param('i', $targetUserId);
        $stmt->execute();
        $stmt->close();
        $message = 'All individual permissions have been reset to group defaults.';
    }
    // Save permissions overrides
    elseif (isset($_POST['save_permissions'])) {
        $permsInput = $_POST['perm'] ?? [];
        $db->begin_transaction();
        $insertStmt = $db->prepare(
            'REPLACE INTO forum_user_permissions (user_id, permission_id, allowed) VALUES (?, ?, ?)'
        );
        $deleteStmt = $db->prepare(
            'DELETE FROM forum_user_permissions WHERE user_id = ? AND permission_id = ?'
        );
        foreach ($permsInput as $permId => $choice) {
            $pid = (int) $permId;
            if ($choice === 'allow' || $choice === 'deny') {
                $allowed = ($choice === 'allow') ? 1 : 0;
                $insertStmt->bind_param('iii', $targetUserId, $pid, $allowed);
                $insertStmt->execute();
            } else { // default
                $deleteStmt->bind_param('ii', $targetUserId, $pid);
                $deleteStmt->execute();
            }
        }
        $insertStmt->close();
        $deleteStmt->close();
        $db->commit();
        $message = 'Permissions updated successfully.';
    }
}

// Fetch target user
$stmt = $db->prepare('SELECT id, username, group_id FROM forum_users WHERE id = ?');
$stmt->bind_param('i', $targetUserId);
$stmt->execute();
$result = $stmt->get_result();
$targetUser = $result->fetch_assoc();
$stmt->close();
if (!$targetUser) {
    exit('User not found.');
}

// Fetch all permissions (id + label)
$perms = [];
$permRes = $db->query('SELECT id, label FROM forum_permissions ORDER BY label');
while ($row = $permRes->fetch_assoc()) {
    $perms[$row['id']] = $row['label'];
}

// Fetch group defaults
$groupDefaults = [];
$stmt = $db->prepare(
    'SELECT permission_id, allowed FROM forum_usergroup_permissions WHERE usergroup_id = ?'
);
$stmt->bind_param('i', $targetUser['group_id']);
$stmt->execute();
$res = $stmt->get_result();
while ($row = $res->fetch_assoc()) {
    $groupDefaults[$row['permission_id']] = (int) $row['allowed'];
}
$stmt->close();

// Fetch user overrides
$userOverrides = [];
$stmt = $db->prepare('SELECT permission_id, allowed FROM forum_user_permissions WHERE user_id = ?');
$stmt->bind_param('i', $targetUserId);
$stmt->execute();
$res = $stmt->get_result();
while ($row = $res->fetch_assoc()) {
    $userOverrides[$row['permission_id']] = (int) $row['allowed'];
}
$stmt->close();
?>
<!DOCTYPE html>
<html>
<head>
    <meta charset="UTF-8">
    <title>Edit Permissions: <?= htmlspecialchars($targetUser['username']) ?></title>
    <link rel="stylesheet" href="../css/admin.css">
</head>
<body>
<div class="dashboard-wrapper">
    <h1>Edit Forum Permissions for <?= htmlspecialchars($targetUser['username']) ?></h1>

    <?php if ($message): ?>
        <div class="alert success"><?= htmlspecialchars($message) ?></div>
    <?php endif; ?>

    <form method="POST">
        <input type="hidden" name="user_id" value="<?= $targetUser['id'] ?>">
        <table class="data-table">
            <thead>
                <tr>
                    <th>Permission</th>
                    <th>Group Default</th>
                    <th>Override</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($perms as $pid => $label):
                    $default = $groupDefaults[$pid] ?? 0;
                    $override = $userOverrides[$pid] ?? null;
                ?>
                <tr>
                    <td><?= htmlspecialchars($label) ?></td>
                    <td><?= $default ? 'Allowed' : 'Denied' ?></td>
                    <td>
                        <select name="perm[<?= $pid ?>]">
                            <option value="default"<?= $override === null ? ' selected' : '' ?>>Default</option>
                            <option value="allow"<?= $override === 1 ? ' selected' : '' ?>>Allow</option>
                            <option value="deny"<?= $override === 0 && $override !== null ? ' selected' : '' ?>>Deny</option>
                        </select>
                    </td>
                </tr>
                <?php endforeach; ?>
            </tbody>
        </table>

        <div class="bulk-action">
            <button type="submit" name="save_permissions">Save Changes</button>
            <button type="submit" name="reset_all" onclick="return confirm('Reset all overrides and return to group defaults?');">Reset All</button>
        </div>
    </form>

    <p><a href="forum_user_manager.php">← Back to User Manager</a></p>
</div>
</body>
</html>
