<?php
// admin/forums/forum_bootstrap.php

// 0) Start session if not active
if (session_status() === PHP_SESSION_NONE) {
    session_start();
}

// 1) Core includes
require_once __DIR__ . '/../../config/db.php';
require_once __DIR__ . '/../auth.php';    // currentUser()
require_once __DIR__ . '/forum_functions.php';

// 2) Bridge SSO for eMS users into forum_users
if ($ems = currentUser()) {
    $stmt = $db->prepare("SELECT * FROM forum_users WHERE ems_user_id = ?");
    $stmt->bind_param('i', $ems['id']);
    $stmt->execute();
    $fu = $stmt->get_result()->fetch_assoc();

    // Provision if not found
    if (!$fu) {
        $email = trim($ems['email'] ?? '');
        $username = trim($ems['username']);
        $ins = $db->prepare("
            INSERT INTO forum_users (ems_user_id, username, email, joined_at)
            VALUES (?, ?, ?, NOW())
        ");
        $ins->bind_param('iss', $ems['id'], $username, $email);
        $ins->execute();
        $fu = [
            'id'            => $ins->insert_id,
            'ems_user_id'   => $ems['id'],
            'username'      => $username,
            'email'         => $email,
            'joined_at'     => date('Y-m-d H:i:s'),
            'group_id'      => 1 // Default to Fan until set
        ];
    }

    // 3) Update last_seen on every request
    $upd = $db->prepare("UPDATE forum_users SET last_seen = NOW() WHERE id = ?");
    $upd->bind_param('i', $fu['id']);
    $upd->execute();

    // 4) Store in session
    $_SESSION['forum_user'] = $fu;
    $_SESSION['forum_user']['forum_group_id'] = (int)($fu['group_id'] ?? 1);
}
?>
