<?php
// forum_functions.php

function hasForumPermission(string $code): bool {
    $user = currentForumUser() ?? currentUser(); // prioritize forum session
    $groupId = (int)($user['forum_group_id'] ?? $user['group_id'] ?? 1);

    // Optional override for Fed Head (group_id = 4)
    if ($groupId === 4) {
        return true;
    }

    global $db;
    static $cached = [];

    if (!isset($cached[$groupId])) {
        $stmt = $db->prepare("
            SELECT fp.code
            FROM forum_usergroup_permissions fgp
            JOIN forum_permissions fp ON fgp.permission_id = fp.id
            WHERE fgp.usergroup_id = ? AND fgp.allowed = 1
        ");
        $stmt->bind_param("i", $groupId);
        $stmt->execute();
        $res = $stmt->get_result();
        $cached[$groupId] = array_column($res->fetch_all(MYSQLI_ASSOC), 'code');
    }

    return in_array($code, $cached[$groupId]);
}



// Check if the current forum user is logged in
function isForumLoggedIn(): bool {
    return isset($_SESSION['forum_user']) && !empty($_SESSION['forum_user']['id']);
}

// Get current forum user (or null)
function currentForumUser(): ?array {
    return $_SESSION['forum_user'] ?? null;
}
