<?php
require_once __DIR__ . '/forum_bootstrap.php';
require_once __DIR__ . '/../auth.php';
requireLogin();

$user = currentUser();
if ((int)$user['group_id'] < 9) {
    exit('Unauthorized');
}

require_once __DIR__ . '/../../config/db.php';

// Soft delete
if (isset($_GET['delete'])) {
    $id = (int)$_GET['delete'];
    $db->query("UPDATE forum_posts SET is_deleted = 1 WHERE id = $id");
    header("Location: posts.php");
    exit;
}

// Handle inline edit
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['edit_id'])) {
    $id = (int)$_POST['edit_id'];
    $content = trim($_POST['edit_content']);
    if ($content !== '') {
        $stmt = $db->prepare("UPDATE forum_posts SET content = ? WHERE id = ?");
        $stmt->bind_param('si', $content, $id);
        $stmt->execute();
    }
    header("Location: posts.php");
    exit;
}

// Fetch posts with topic and user info
$result = $db->query("
    SELECT p.id, p.content, p.created_at, u.username, t.title AS topic_title, t.slug AS topic_slug
    FROM forum_posts p
    LEFT JOIN users u ON u.id = p.user_id
    LEFT JOIN forum_topics t ON t.id = p.topic_id
    WHERE p.is_deleted = 0
    ORDER BY p.created_at DESC
    LIMIT 50
");
$posts = $result->fetch_all(MYSQLI_ASSOC);
?>
<!DOCTYPE html>
<html>
<head>
    <meta charset="UTF-8">
    <title>Moderate Forum Posts</title>
    <link rel="stylesheet" href="../css/admin.css">
</head>
<body>
<div class="dashboard-wrapper">
    <h1>Moderate Posts</h1>

    <?php if (empty($posts)): ?>
        <p>No posts found.</p>
    <?php else: ?>
        <table class="admin-table">
            <thead>
                <tr>
                    <th>Post</th>
                    <th>User</th>
                    <th>Topic</th>
                    <th>Time</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
            <?php foreach ($posts as $p): ?>
                <tr>
                    <form method="post">
                        <input type="hidden" name="edit_id" value="<?= $p['id'] ?>">
                        <td><textarea name="edit_content" rows="4"><?= htmlspecialchars($p['content']) ?></textarea></td>
                        <td><?= htmlspecialchars($p['username'] ?? 'Guest') ?></td>
                        <td><a href="/forums/topic/<?= htmlspecialchars($p['topic_slug']) ?>" target="_blank"><?= htmlspecialchars($p['topic_title']) ?></a></td>
                        <td><?= date('M j, Y g:ia', strtotime($p['created_at'])) ?></td>
                        <td>
                            <button type="submit">Save</button><br>
                            <a href="?delete=<?= $p['id'] ?>" onclick="return confirm('Delete this post?')">Delete</a>
                        </td>
                    </form>
                </tr>
            <?php endforeach ?>
            </tbody>
        </table>
    <?php endif ?>
</div>
</body>
</html>
