<?php
ini_set('display_errors', 1);
error_reporting(E_ALL);


require_once __DIR__ . '/forum_bootstrap.php';
require_once __DIR__ . '/../auth.php';
requireLogin();

$user = currentUser();
if ((int)$user['group_id'] < 9) {
    exit('Unauthorized');
}

require_once __DIR__ . '/../../config/db.php';

// Soft delete
if (isset($_GET['delete'])) {
    $id = (int)$_GET['delete'];
    $db->query("UPDATE forum_topics SET is_deleted = 1 WHERE id = $id");
    header("Location: topics.php");
    exit;
}

// Lock/unlock toggle
if (isset($_GET['toggle_lock'])) {
    $id = (int)$_GET['toggle_lock'];
    $db->query("UPDATE forum_topics SET is_locked = IFNULL(is_locked, 0) ^ 1 WHERE id = $id");
    header("Location: topics.php");
    exit;
}

// Fetch topics
$result = $db->query("
    SELECT t.id, t.title, t.slug, t.created_at, t.is_locked,
           c.name AS category_name
    FROM forum_topics t
    JOIN forum_categories c ON t.category_id = c.id
    WHERE t.is_deleted = 0
    ORDER BY t.created_at DESC
");
$topics = $result->fetch_all(MYSQLI_ASSOC);
?>
<!DOCTYPE html>
<html>
<head>
    <meta charset="UTF-8">
    <title>Moderate Forum Topics</title>
    <link rel="stylesheet" href="../css/admin.css">
</head>
<body>
<div class="dashboard-wrapper">
    <h1>Moderate Topics</h1>

    <?php if (empty($topics)): ?>
        <p>No topics found.</p>
    <?php else: ?>
        <table class="admin-table">
            <thead>
                <tr>
                    <th>Title</th>
                    <th>Category</th>
                    <th>Created</th>
                    <th>Locked</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
            <?php foreach ($topics as $t): ?>
                <tr>
                    <td><a href="/forums/topic/<?= htmlspecialchars($t['slug']) ?>" target="_blank">
                        <?= htmlspecialchars($t['title']) ?>
                    </a></td>
                    <td><?= htmlspecialchars($t['category_name']) ?></td>
                    <td><?= date('M j, Y', strtotime($t['created_at'])) ?></td>
                    <td><?= $t['is_locked'] ? 'Yes' : 'No' ?></td>
                    <td>
                        <a href="?toggle_lock=<?= $t['id'] ?>">
                            <?= $t['is_locked'] ? 'Unlock' : 'Lock' ?>
                        </a> |
                        <a href="?delete=<?= $t['id'] ?>" onclick="return confirm('Delete this topic?')">Delete</a>
                    </td>
                </tr>
            <?php endforeach ?>
            </tbody>
        </table>
    <?php endif ?>
</div>
</body>
</html>
