<?php
// user_content/edit-topic-post.php

require_once __DIR__ . '/../admin/forums/forum_bootstrap.php';
require_once __DIR__ . '/../config/db.php';

$currentUser = currentForumUser();
$isMod = hasForumPermission('can_moderate_topics');

if (!isForumLoggedIn() || !$currentUser) {
    exit('<p>You must be logged in to edit a post.</p>');
}

$postId = isset($_GET['id']) ? (int)$_GET['id'] : 0;
if (!$postId) {
    exit('<p>Invalid post ID.</p>');
}

// Fetch post and topic info
$stmt = $db->prepare("SELECT p.id, p.user_id, p.content, t.id AS topic_id, t.slug AS topic_slug, t.title AS topic_title, t.is_locked, t.is_pinned FROM forum_posts p JOIN forum_topics t ON t.id = p.topic_id WHERE p.id = ? AND p.is_deleted = 0");
$stmt->bind_param('i', $postId);
$stmt->execute();
$post = $stmt->get_result()->fetch_assoc();
$stmt->close();

if (!$post) {
    exit('<p>Post not found.</p>');
}

// Permissions
if ($currentUser['id'] !== (int)$post['user_id'] && !$isMod) {
    exit('<p>You do not have permission to edit this post.</p>');
}

$error = '';
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $content = trim($_POST['post_content'] ?? '');
    if ($content === '' || $content === '<p><br></p>') {
        $error = 'Content cannot be empty.';
    } else {
        $update = $db->prepare("UPDATE forum_posts SET content = ? WHERE id = ?");
        $update->bind_param('si', $content, $postId);
        $update->execute();

        if ($isMod) {
            $isLocked = isset($_POST['is_locked']) ? 1 : 0;
            $isPinned = isset($_POST['is_pinned']) ? 1 : 0;
            $topicUpdate = $db->prepare("UPDATE forum_topics SET is_locked = ?, is_pinned = ? WHERE id = ?");
            $topicUpdate->bind_param('iii', $isLocked, $isPinned, $post['topic_id']);
            $topicUpdate->execute();
        }

        echo "<script>window.location.href = '/forums/topic/" . urlencode($post['topic_slug']) . "?id=" . (int)$post['topic_id'] . "';</script>";
        exit;
    }
}

?>
<!DOCTYPE html>
<html>
<head>
  <meta charset="UTF-8">
  <title>Edit Post</title>
  <script src="/js/tinymce/tinymce.min.js" referrerpolicy="origin"></script>
  <link rel="stylesheet" href="/css/forum.css">
<link
  rel="stylesheet"
  href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css"
  integrity="sha512-p+w1Xb...YOUR_INTEGRITY_HASH...=="
  crossorigin="anonymous"
  referrerpolicy="no-referrer"
/>

</head>
<body>
<div class="card forum-topic">
<div class="breadcrumbs">
        <a href="/forums">Forums</a> &raquo;
        Edit Topic
    </div>
  <h1>Edit Your Post</h1>
  <?php if ($error): ?><p class="error"><?= htmlspecialchars($error) ?></p><?php endif; ?>
  <form method="post">
    <textarea id="post-content" name="post_content"><?= htmlspecialchars($post['content']) ?></textarea>
    <?php if ($isMod): ?>
      <div class="mod-controls">
        <label><input type="checkbox" name="is_locked" <?= $post['is_locked'] ? 'checked' : '' ?>> Locked</label>
        <label><input type="checkbox" name="is_pinned" <?= $post['is_pinned'] ? 'checked' : '' ?>> Pinned</label>
      </div>
    <?php endif; ?>
    <br><button type="submit">Save</button>
  </form>
</div>
<script>
  tinymce.init({
    selector: '#post-content',
    height: 400,
    skin: 'oxide-dark',
    plugins: 'advlist autolink lists link image charmap preview anchor searchreplace visualblocks code fullscreen insertdatetime media table code help wordcount emoticons hr',
    toolbar: 'undo redo | blocks | bold italic underline strikethrough removeformat | alignleft aligncenter alignright alignjustify | bullist numlist outdent indent | link media table hr emoticons charmap | code fullscreen preview help',
    branding: false,
    content_style: 'body { font-family:Helvetica,Arial,sans-serif; font-size:14px }',
    setup: function (editor) {
      editor.on('change', function () {
        editor.save();
      });
    }
  });
</script>
</body>
</html>
