<?php
// user_content/edit_user.php

if (session_status() === PHP_SESSION_NONE) session_start();

require_once __DIR__ . '/../admin/forums/forum_bootstrap.php';
require_once __DIR__ . '/../config/db.php';

$fu = $_SESSION['forum_user'] ?? null;
if (empty($fu['id'])) {
    echo "<script>window.location.href = '/forums';</script>";
    exit;
}
$userId = (int)$fu['id'];

$error = $success = '';
$socials = [
    'discord', 'facebook', 'instagram', 'threads', 'twitter', 'bluesky',
    'tiktok', 'twitch', 'youtube_url', 'website_url'
];

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $avatar    = trim($_POST['avatar_url'] ?? '');
    $signature = trim($_POST['signature'] ?? '');
    $name      = trim($_POST['name'] ?? '');
    $birthday  = trim($_POST['birthday'] ?? '') ?: null;
    $bio       = trim($_POST['bio'] ?? '');

    $socialVals = [];
    foreach ($socials as $s) {
        $socialVals[$s] = trim($_POST[$s] ?? '');
    }

    if (strlen($avatar) > 255) {
        $error = "Avatar URL is too long.";
    } elseif (strlen($bio) > 300) {
        $error = "Bio must be 300 characters or less.";
    } else {
        $sql = "UPDATE forum_users SET avatar_url=?, signature=?, name=?, birthday=?, bio=?, discord=?, facebook=?, instagram=?, threads=?, twitter=?, bluesky=?, tiktok=?, twitch=?, youtube_url=?, website_url=? WHERE id=?";
        $stmt = $db->prepare($sql);
        $stmt->bind_param(
            str_repeat('s', 15) . 'i',
            $avatar,
            $signature,
            $name,
            $birthday,
            $bio,
            $socialVals['discord'],
            $socialVals['facebook'],
            $socialVals['instagram'],
            $socialVals['threads'],
            $socialVals['twitter'],
            $socialVals['bluesky'],
            $socialVals['tiktok'],
            $socialVals['twitch'],
            $socialVals['youtube_url'],
            $socialVals['website_url'],
            $userId
        );
        $stmt->execute();

        $_SESSION['forum_user']['avatar_url'] = $avatar;
        $_SESSION['forum_user']['signature']  = $signature;
        $success = "Profile updated successfully.";
    }
}

// Reload user
global $user;
$stmt = $db->prepare("SELECT username, avatar_url, signature, name, birthday, bio, discord, facebook, instagram, threads, twitter, bluesky, tiktok, twitch, youtube_url, website_url, joined_at, last_seen FROM forum_users WHERE id=?");
$stmt->bind_param("i", $userId);
$stmt->execute();
$user = $stmt->get_result()->fetch_assoc();

foreach (['avatar_url','signature','name','birthday','bio'] as $field) {
    if (!isset($user[$field])) $user[$field] = '';
}
foreach ($socials as $s) {
    if (!isset($user[$s])) $user[$s] = '';
}
?>
<!DOCTYPE html>
<html>
<head>
  <meta charset="UTF-8">
  <title>Edit Profile: <?= htmlspecialchars($user['username']) ?></title>
  <link rel="stylesheet" href="/css/forum.css">
<link
  rel="stylesheet"
  href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css"
  integrity="sha512-p+w1Xb...YOUR_INTEGRITY_HASH...=="
  crossorigin="anonymous"
  referrerpolicy="no-referrer"
/>

</head>
<body>
  <div class="forum-profile edit">
<div class="breadcrumbs">
        <a href="/forums">Forums</a> &raquo;
    Edit Profile
    </div>
    <h1>Edit Your Profile</h1>

    <?php if ($error): ?>
      <div class="form-error"><?= htmlspecialchars($error) ?></div>
    <?php elseif ($success): ?>
      <div class="form-success"><?= htmlspecialchars($success) ?></div>
    <?php endif; ?>

    <form method="POST" class="profile-edit-form">
      <div class="form-row">
        <label for="avatar_url">Avatar URL</label>
        <input type="url" id="avatar_url" name="avatar_url" value="<?= htmlspecialchars($user['avatar_url']) ?>">
      </div>

      <div class="form-row">
        <label for="name">Display Name</label>
        <input type="text" id="name" name="name" value="<?= htmlspecialchars($user['name']) ?>">
      </div>

      <div class="form-row">
        <label for="birthday">Birthday</label>
        <input type="date" id="birthday" name="birthday" value="<?= htmlspecialchars($user['birthday']) ?>">
      </div>

      <div class="form-row">
        <label for="bio">Short Bio (300 characters max)</label>
        <textarea id="bio" name="bio" maxlength="300" rows="3"><?= htmlspecialchars($user['bio']) ?></textarea>
      </div>

      <div class="form-row">
        <label for="signature">Signature</label>
        <textarea id="signature" name="signature" rows="3"><?= htmlspecialchars($user['signature']) ?></textarea>
      </div>

      <?php foreach ($socials as $s):
        $label = ucfirst(
          $s === 'twitter' ? 'Twitter/X' :
          ($s === 'youtube_url' ? 'YouTube' :
          ($s === 'website_url' ? 'Website' : $s)));
      ?>
      <div class="form-row">
        <label for="<?= $s ?>"><?= $label ?> Username</label>
        <input type="text" id="<?= $s ?>" name="<?= $s ?>" value="<?= htmlspecialchars($user[$s]) ?>">
      </div>
      <?php endforeach; ?>

      <div class="form-row meta-info">
        <small>
          Joined: <?= date('M j, Y', strtotime($user['joined_at'])) ?> |
          Last Seen: <?= $user['last_seen'] ? date('M j, Y g:ia', strtotime($user['last_seen'])) : 'Never' ?>
        </small>
      </div>

      <div class="form-row">
        <button type="submit" class="btn">Save Changes</button>
        <a href="/forums/user/<?= urlencode($user['username']) ?>" class="btn-cancel">Cancel</a>
      </div>
    </form>
  </div>
</body>
</html>
