<?php
// user_content/view_category.php
require_once __DIR__ . '/../admin/forums/forum_bootstrap.php';
require_once __DIR__ . '/../config/db.php';

if (!hasForumPermission('can_view_topics')) {
    echo "<p>You do not have permission to view forum categories.</p>";
    exit;
}

$forumUser = currentForumUser();

if (!empty($_GET['id'])) {
    $stmt = $db->prepare("SELECT id, name, slug, description, is_locked FROM forum_categories WHERE id=? AND is_deleted=0");
    $stmt->bind_param('i', $_GET['id']);
} else {
    $stmt = $db->prepare("SELECT id, name, slug, description, is_locked FROM forum_categories WHERE slug=? AND is_deleted=0");
    $stmt->bind_param('s', $_GET['slug']);
}
$stmt->execute();
$cat = $stmt->get_result()->fetch_assoc();
if (!$cat) {
    echo "<p>Category not found.</p>"; exit;
}

$bc = [['Forums','/forums'], [$cat['name'],null]];

$topics = $db->prepare("SELECT t.id, t.title, t.slug, t.created_at, t.is_pinned, t.is_locked,
  (SELECT COUNT(*) FROM forum_posts p WHERE p.topic_id=t.id AND p.is_deleted=0) AS replies,
  (SELECT fu.username FROM forum_posts p JOIN forum_users fu ON fu.id=p.user_id WHERE p.topic_id=t.id AND p.is_deleted=0 ORDER BY p.created_at DESC LIMIT 1) AS last_user,
  (SELECT p.created_at FROM forum_posts p WHERE p.topic_id=t.id AND p.is_deleted=0 ORDER BY p.created_at DESC LIMIT 1) AS last_post
  FROM forum_topics t
  WHERE t.category_id=? AND t.is_deleted=0
  ORDER BY t.is_pinned DESC, t.created_at DESC");
$topics->bind_param('i', $cat['id']);
$topics->execute();
$rows = $topics->get_result()->fetch_all(MYSQLI_ASSOC);

// Child categories
$subStmt = $db->prepare("SELECT id, name, slug, description FROM forum_categories WHERE parent_id = ? AND is_deleted = 0 ORDER BY sort_order, name");
$subStmt->bind_param('i', $cat['id']);
$subStmt->execute();
$subCats = $subStmt->get_result()->fetch_all(MYSQLI_ASSOC);

$latestStmt = $db->prepare("SELECT t.title, t.slug, fu.username, p.created_at FROM forum_posts p
  JOIN forum_topics t ON t.id = p.topic_id AND t.is_deleted = 0
  LEFT JOIN forum_users fu ON fu.id = p.user_id
  WHERE t.category_id = ? AND p.is_deleted = 0
  ORDER BY p.created_at DESC
  LIMIT 2");
?>
<!DOCTYPE html>
<html>
<head>
  <meta charset="UTF-8">
  <title><?= htmlspecialchars($cat['name']) ?> &mdash; Forum</title>
  <link rel="stylesheet" href="/css/forum.css">
<link
  rel="stylesheet"
  href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css"
  integrity="sha512-p+w1Xb...YOUR_INTEGRITY_HASH...=="
  crossorigin="anonymous"
  referrerpolicy="no-referrer"
/>

</head>
<body>
  <div class="card forum-category">

    <nav class="breadcrumbs">
      <a href="/">Home</a> &raquo;
      <a href="/forums">Forums</a> &raquo;
      <span><?=htmlspecialchars($cat['name'])?></span>
    </nav>

    <h1><?=htmlspecialchars($cat['name'])?></h1>
<?php if (!empty($subCats)): ?>
      
      <table class="forum-table">
        <thead>
          <tr>
            <th>Forum</th>
            <th>Latest Topics</th>
          </tr>
        </thead>
        <tbody>
        <?php foreach ($subCats as $sc):
            $tc = $db->query("SELECT COUNT(*) FROM forum_topics WHERE category_id={$sc['id']} AND is_deleted=0")->fetch_row()[0];
            $pc = $db->query("SELECT COUNT(*) FROM forum_posts p JOIN forum_topics t ON t.id=p.topic_id WHERE t.category_id={$sc['id']} AND p.is_deleted=0")->fetch_row()[0];

            $latestStmt->bind_param('i', $sc['id']);
            $latestStmt->execute();
            $lats = $latestStmt->get_result()->fetch_all(MYSQLI_ASSOC);
        ?>
          <tr class="parent-forum">
            <td>
              <i class="fas fa-folder"></i>
              <a href="/forums/<?=htmlspecialchars($sc['slug'])?>">
                <?=htmlspecialchars($sc['name'])?>
              </a>
              <?php if($sc['description']):?>
                <div class="desc"><?=htmlspecialchars($sc['description'])?></div>
              <?php endif;?>
              <div class="counts">
                <small><?= $tc ?> Threads &bull; <?= $pc ?> Posts</small>
              </div>
            </td>
            <td class="latest">
              <?php if(count($lats)): ?>
                <?php foreach($lats as $lat): ?>
                  <div class="topic-line">
                    <a href="/forums/topic/<?=htmlspecialchars($lat['slug'])?>">
                      <?=htmlspecialchars($lat['title'])?>
                    </a>
                    <div class="meta">
                      by <?=htmlspecialchars($lat['username']?:'Guest')?>
                      on <?=date('M j, Y',strtotime($lat['created_at']))?>
                    </div>
                  </div>
                <?php endforeach; ?>
              <?php else: ?>
                <div class="no-posts">No posts yet</div>
              <?php endif; ?>
            </td>
          </tr>
        <?php endforeach; ?>
        </tbody>
      </table>
    <?php endif; ?>

    <?php if (!$cat['is_locked'] && hasForumPermission('can_post_topic')): ?>
      <p align="right"><a href="/forums/<?=htmlspecialchars($cat['slug'])?>/new" class="btn">New Topic</a></p>
    <?php elseif ($cat['is_locked']): ?>
      <p class="locked-notice"><strong>This forum is locked. No new topics can be posted.</strong></p>
    <?php endif; ?>

    <table class="topic-table">
      <thead>
        <tr>
          <th>Topic</th>
          <th>Replies</th>
          <th>Last Post</th>
        </tr>
      </thead>
      <tbody>
        <?php if (!$rows): ?>
          <tr><td colspan="3" class="no-topics">No topics yet.</td></tr>
        <?php else: foreach($rows as $r): ?>
          <tr>
            <td class="topic-col">
              <i class="fas fa-comment-alt"></i>
              <?php if (!empty($r['is_pinned'])): ?><span class="pinned-badge">📌</span><?php endif; ?>
              <?php if (!empty($r['is_locked'])): ?><span class="locked-badge">🔒</span><?php endif; ?>
              <a href="/forums/topic/<?=htmlspecialchars($r['slug'])?>">
                <?=htmlspecialchars($r['title'])?>
              </a><br>
              <small class="meta">
                by <?=htmlspecialchars($r['last_user'] ?: 'Unknown')?> on <?=date('M j, Y',strtotime($r['created_at']))?>
              </small>
            </td>
            <td class="replies-col"><?= $r['replies'] ?></td>
            <td class="last-col">
              <?php if($r['last_user']): ?>
                <small>
                  by <?=htmlspecialchars($r['last_user'])?><br>
                  <?=date('M j, Y g:ia',strtotime($r['last_post']))?>
                </small>
              <?php else: ?>
                <small class="no-posts">—</small>
              <?php endif?>
            </td>
          </tr>
        <?php endforeach; endif?>
      </tbody>
    </table>

  </div>
</body>
</html>
