<?php
// user_content/view_topic.php

ob_start();

require_once __DIR__ . '/../admin/forums/forum_bootstrap.php';
require_once __DIR__ . '/../config/db.php';

$currentUser = currentForumUser();
$isMod = hasForumPermission('can_moderate_topics');

if (!hasForumPermission('can_view_topics')) {
    exit('<p>You do not have permission to view this topic.</p>');
}

if (isset($_GET['action'], $_GET['id'], $_GET['slug']) && $_GET['action']==='toggle_lock' && ($currentUser['group_id'] ?? 0) >= 9) {
    $stmt = $db->prepare("UPDATE forum_topics SET is_locked = 1 - is_locked WHERE id = ?");
    $stmt->bind_param('i', $_GET['id']);
    $stmt->execute();
    echo "<script>window.location.href = '/forums/topic/" . urlencode($_GET['slug']) . "?id=" . ((int)$_GET['id']) . "';</script>";
    exit;
}

if (!empty($_GET['id'])) {
    $stmt = $db->prepare("SELECT t.id, t.title, t.slug, t.category_id, t.is_locked, c.slug AS cat_slug, c.name AS cat_name, c.parent_id FROM forum_topics t JOIN forum_categories c ON c.id = t.category_id WHERE t.id = ? AND t.is_deleted = 0");
    $stmt->bind_param('i', $_GET['id']);
} elseif (!empty($_GET['slug'])) {
    $stmt = $db->prepare("SELECT t.id, t.title, t.slug, t.category_id, t.is_locked, c.slug AS cat_slug, c.name AS cat_name, c.parent_id FROM forum_topics t JOIN forum_categories c ON c.id = t.category_id WHERE t.slug = ? AND t.is_deleted = 0");
    $stmt->bind_param('s', $_GET['slug']);
} else {
    exit('<p>Invalid topic identifier.</p>');
}
$stmt->execute();
$topic = $stmt->get_result()->fetch_assoc();
if (!$topic) exit('<p>Topic not found.</p>');

$error = '';
if (!$topic['is_locked'] && $_SERVER['REQUEST_METHOD']==='POST' && isset($_POST['reply_content'])) {
    $content = trim($_POST['reply_content']);
    if ($content==='' || $content==='<p><br></p>') {
        $error = "Reply cannot be empty.";
    } else {
        if (!isForumLoggedIn()) {
            exit('<p>You must be logged in to reply.</p>');
        }
        if (!hasForumPermission('can_reply_topics')) {
            exit('<p>You do not have permission to reply to topics.</p>');
        }
        $fu = currentForumUser();

        $ins = $db->prepare("INSERT INTO forum_posts (topic_id,user_id,content,created_at) VALUES (?,?,?,NOW())");
        $ins->bind_param('iis', $topic['id'], $fu['id'], $content);
        $ins->execute();

        echo "<script>window.location.href = '/forums/topic/{$topic['slug']}?id={$topic['id']}';</script>";
        exit;
    }
}

$ps = $db->prepare("SELECT p.id,p.user_id,p.content,p.created_at, fu.username,fu.avatar_url,fu.signature,fu.joined_at,fu.last_seen, fu.website_url, fu.twitter, fu.instagram, fu.facebook, fu.youtube_url, fu.tiktok, fu.bluesky, fu.discord, fu.threads, fu.twitch, fg.name AS group_name FROM forum_posts p LEFT JOIN forum_users fu ON fu.id=p.user_id LEFT JOIN forum_usergroups fg ON fu.group_id = fg.id WHERE p.topic_id=? AND p.is_deleted=0 ORDER BY p.created_at ASC");
$ps->bind_param('i',$topic['id']);
$ps->execute();
$posts = $ps->get_result()->fetch_all(MYSQLI_ASSOC);

$bc = [['Forums','/forums']];
if ($topic['parent_id']) {
    $p = $db->prepare("SELECT name,slug FROM forum_categories WHERE id=?");
    $p->bind_param('i',$topic['parent_id']);
    $p->execute();
    $par = $p->get_result()->fetch_assoc();
    if ($par) $bc[] = [$par['name'], "/forums/{$par['slug']}"];
}
$bc[] = [$topic['cat_name'], "/forums/{$topic['cat_slug']}"];
$bc[] = [$topic['title'], null];

ob_end_flush();

function socBadge($url, $iconClass) {
  return '<a href="' . htmlspecialchars($url) . '" target="_blank" style="background: var(--forum-bg); padding: 6px; margin: 2px; border-radius: 4px; display: inline-block;"><i class="' . $iconClass . '" style="font-size:14px;"></i></a>';
}
?>
<!DOCTYPE html>
<html>
<head>
  <meta charset="UTF-8">
  <title><?= htmlspecialchars($topic['title']) ?></title>
  <link rel="stylesheet" href="/css/forum.css">
  <script src="/js/tinymce/tinymce.min.js" referrerpolicy="origin"></script>
<link
  rel="stylesheet"
  href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css"
  integrity="sha512-p+w1Xb...YOUR_INTEGRITY_HASH...=="
  crossorigin="anonymous"
  referrerpolicy="no-referrer"
/>
</head>
<body>
<div class="card forum-topic">
  <nav class="breadcrumbs">
    <a href="/">Home</a> &raquo;
    <?php foreach($bc as $crumb): ?>
      <?php if($crumb[1]): ?>
        <a href="<?=htmlspecialchars($crumb[1])?>"><?=htmlspecialchars($crumb[0])?></a> &raquo;
      <?php else: ?>
        <span><?=htmlspecialchars($crumb[0])?></span>
      <?php endif;?>
    <?php endforeach;?>
  </nav>

  <div class="forum-header">
    <h1><?= htmlspecialchars($topic['title']) ?></h1>
    <?php if ($topic['is_locked']): ?><span class="locked-badge">🔒 Locked</span><?php endif; ?>
  </div>

  <?php foreach($posts as $i=>$post): ?>
    <div class="post-row <?= $i===0 ? 'original-post' : 'reply-post' ?>">
      <div class="post-content">
        <div class="meta">
          Posted by 
          <strong><a href="/forums/user/<?= urlencode($post['username']) ?>"><?= htmlspecialchars($post['username']) ?></a></strong>
          on <?= date('M j, Y g:ia', strtotime($post['created_at'])) ?>
          <?php if (($currentUser && $currentUser['id'] === (int)$post['user_id']) || $isMod): ?>
            <a href="/forums/edit-topic-post/<?= $post['id'] ?>" class="quote-btn" style="float: right; margin-left: 10px;">Edit</a>
          <?php endif; ?>
          <?php if(!$topic['is_locked'] && hasForumPermission('can_reply_topics')): ?>
            <button class="quote-btn" data-post-id="<?=$post['id']?>">Quote</button>
          <?php endif;?>
        </div>
        <div class="content"><?= $post['content'] ?></div>
        <?php if($post['signature']): ?>
          <div class="signature"><?= nl2br(htmlspecialchars($post['signature'])) ?></div>
        <?php endif;?>
      </div>
      <div class="post-userbox">
        <img src="<?=htmlspecialchars($post['avatar_url']?:'/images/default-avatar.png')?>" class="profile-avatar" alt="">
        <div class="user-meta">
          <strong><?=htmlspecialchars($post['username'])?></strong>
          <i><?=htmlspecialchars($post['group_name'] ?? '')?></i>
          <?php if (
            !empty($post['discord']) || !empty($post['facebook']) || !empty($post['instagram']) || !empty($post['threads']) ||
            !empty($post['twitter']) || !empty($post['bluesky']) || !empty($post['tiktok']) || !empty($post['twitch']) ||
            !empty($post['youtube_url']) || !empty($post['website_url'])
          ): ?>
          <div class="social-icons">
            <?php
            if (!empty($post['discord']))    echo socBadge("https://discord.gg/{$post['discord']}", 'fab fa-discord');
            if (!empty($post['facebook']))    echo socBadge("https://facebook.com/{$post['facebook']}", 'fab fa-facebook');
            if (!empty($post['instagram']))   echo socBadge("https://instagram.com/{$post['instagram']}", 'fab fa-instagram');
            if (!empty($post['threads']))     echo socBadge("https://www.threads.net/{$post['threads']}", 'fa-solid fa-hashtag');
            if (!empty($post['twitter']))     echo socBadge("https://x.com/{$post['twitter']}", 'fab fa-twitter');
            if (!empty($post['bluesky']))     echo socBadge("https://bsky.app/profile/{$post['bluesky']}", 'fa-solid fa-link');
            if (!empty($post['tiktok']))      echo socBadge("https://tiktok.com/@{$post['tiktok']}", 'fab fa-tiktok');
            if (!empty($post['twitch']))      echo socBadge("https://twitch.tv/{$post['twitch']}", 'fab fa-twitch');
            if (!empty($post['youtube_url'])) echo socBadge("https://www.youtube.com/@{$post['youtube_url']}", 'fab fa-youtube');
            if (!empty($post['website_url'])) echo socBadge($post['website_url'], 'fa-solid fa-globe');
            ?>
          </div>
          <?php endif; ?>
          <p><br><strong>Last seen:</strong> <?= $post['last_seen'] ? date('M j g:ia',strtotime($post['last_seen'])) : 'Never' ?>
        </div>
      </div>
    </div>
  <?php endforeach;?>

  <?php if (!isForumLoggedIn() || !hasForumPermission('can_reply_topics')): ?>
    <p class="error">You do not have permission to reply to topics.</p>
  <?php elseif ($topic['is_locked']): ?>
    <p class="error">This topic is locked. No new replies allowed.</p>
  <?php else: ?>
    <div class="reply-form"><hr>
      <h2>Leave a Reply</h2>
      <?php if($error): ?><p class="error"><?=htmlspecialchars($error)?></p><?php endif;?>
      <form id="replyForm" method="POST">
        <textarea id="reply-content" name="reply_content"><?=htmlspecialchars($_POST['reply_content']??'')?></textarea>
        <button type="submit">Post Reply</button>
      </form>
    </div>
  <?php endif;?>
</div>

<script>
document.addEventListener('DOMContentLoaded', () => {
  tinymce.init({
    selector: '#reply-content',
    height: 400,
    menubar: 'file edit view insert format tools table help',
    plugins: ['advlist', 'autolink', 'lists', 'link', 'image', 'charmap', 'preview', 'anchor', 'searchreplace', 'visualblocks', 'code', 'fullscreen', 'insertdatetime', 'media', 'table', 'code', 'help', 'wordcount', 'emoticons', 'hr'],
    toolbar: ['undo redo | blocks | bold italic underline strikethrough removeformat | alignleft aligncenter alignright alignjustify', 'bullist numlist outdent indent | link media table hr emoticons charmap | code fullscreen preview help'],
    branding: false,
    license_key: 'gpl',
  content_css: false,
 skin: 'oxide-dark', 
     content_style: 'body { font-family:Helvetica,Arial,sans-serif; font-size:14px }',
    setup: function (editor) {
      editor.on('change', function () {
        editor.save();
      });
    }
  });

  document.querySelectorAll('.quote-btn').forEach(btn => {
    btn.addEventListener('click', () => {
      let row = btn.closest('.post-row'),
          author = row.querySelector('.meta strong').innerText,
          html = row.querySelector('.content').innerHTML,
          quote = `<blockquote class="quoted"><p><strong>${author}</strong> wrote:</p><p>${html}</p></blockquote><p><br></p>`;
      const editor = tinymce.get('reply-content');
      if (editor) {
        editor.setContent(quote);
        editor.focus();
      }
    });
  });
});
</script>
</body>
</html>
